==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/awscdk/IntegrationTestCommonOptions.java <==
package io.github.cdklabs.projen.awscdk;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.611Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.IntegrationTestCommonOptions")
@software.amazon.jsii.Jsii.Proxy(IntegrationTestCommonOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IntegrationTestCommonOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Destroy the test app after a successful deployment.
     * <p>
     * If disabled, leaves the
     * app deployed in the dev account.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getDestroyAfterDeploy() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link IntegrationTestCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link IntegrationTestCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<IntegrationTestCommonOptions> {
        java.lang.Boolean destroyAfterDeploy;

        /**
         * Sets the value of {@link IntegrationTestCommonOptions#getDestroyAfterDeploy}
         * @param destroyAfterDeploy Destroy the test app after a successful deployment.
         *                           If disabled, leaves the
         *                           app deployed in the dev account.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder destroyAfterDeploy(java.lang.Boolean destroyAfterDeploy) {
            this.destroyAfterDeploy = destroyAfterDeploy;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link IntegrationTestCommonOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public IntegrationTestCommonOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link IntegrationTestCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements IntegrationTestCommonOptions {
        private final java.lang.Boolean destroyAfterDeploy;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.destroyAfterDeploy = software.amazon.jsii.Kernel.get(this, "destroyAfterDeploy", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.destroyAfterDeploy = builder.destroyAfterDeploy;
        }

        @Override
        public final java.lang.Boolean getDestroyAfterDeploy() {
            return this.destroyAfterDeploy;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDestroyAfterDeploy() != null) {
                data.set("destroyAfterDeploy", om.valueToTree(this.getDestroyAfterDeploy()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.awscdk.IntegrationTestCommonOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            IntegrationTestCommonOptions.Jsii$Proxy that = (IntegrationTestCommonOptions.Jsii$Proxy) o;

            return this.destroyAfterDeploy != null ? this.destroyAfterDeploy.equals(that.destroyAfterDeploy) : that.destroyAfterDeploy == null;
        }

        @Override
        public final int hashCode() {
            int result = this.destroyAfterDeploy != null ? this.destroyAfterDeploy.hashCode() : 0;
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/awscdk/IntegrationTestCommonOptions.java <==
package io.github.cdklabs.projen.awscdk;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.282Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.IntegrationTestCommonOptions")
@software.amazon.jsii.Jsii.Proxy(IntegrationTestCommonOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IntegrationTestCommonOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Destroy the test app after a successful deployment.
     * <p>
     * If disabled, leaves the
     * app deployed in the dev account.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getDestroyAfterDeploy() {
        return null;
    }

    /**
     * (experimental) Enables path metadata, adding <code>aws:cdk:path</code>, with the defining construct's path, to the CloudFormation metadata for each synthesized resource.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getPathMetadata() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link IntegrationTestCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link IntegrationTestCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<IntegrationTestCommonOptions> {
        java.lang.Boolean destroyAfterDeploy;
        java.lang.Boolean pathMetadata;

        /**
         * Sets the value of {@link IntegrationTestCommonOptions#getDestroyAfterDeploy}
         * @param destroyAfterDeploy Destroy the test app after a successful deployment.
         *                           If disabled, leaves the
         *                           app deployed in the dev account.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder destroyAfterDeploy(java.lang.Boolean destroyAfterDeploy) {
            this.destroyAfterDeploy = destroyAfterDeploy;
            return this;
        }

        /**
         * Sets the value of {@link IntegrationTestCommonOptions#getPathMetadata}
         * @param pathMetadata Enables path metadata, adding <code>aws:cdk:path</code>, with the defining construct's path, to the CloudFormation metadata for each synthesized resource.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pathMetadata(java.lang.Boolean pathMetadata) {
            this.pathMetadata = pathMetadata;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link IntegrationTestCommonOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public IntegrationTestCommonOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link IntegrationTestCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements IntegrationTestCommonOptions {
        private final java.lang.Boolean destroyAfterDeploy;
        private final java.lang.Boolean pathMetadata;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.destroyAfterDeploy = software.amazon.jsii.Kernel.get(this, "destroyAfterDeploy", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.pathMetadata = software.amazon.jsii.Kernel.get(this, "pathMetadata", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.destroyAfterDeploy = builder.destroyAfterDeploy;
            this.pathMetadata = builder.pathMetadata;
        }

        @Override
        public final java.lang.Boolean getDestroyAfterDeploy() {
            return this.destroyAfterDeploy;
        }

        @Override
        public final java.lang.Boolean getPathMetadata() {
            return this.pathMetadata;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDestroyAfterDeploy() != null) {
                data.set("destroyAfterDeploy", om.valueToTree(this.getDestroyAfterDeploy()));
            }
            if (this.getPathMetadata() != null) {
                data.set("pathMetadata", om.valueToTree(this.getPathMetadata()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.awscdk.IntegrationTestCommonOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            IntegrationTestCommonOptions.Jsii$Proxy that = (IntegrationTestCommonOptions.Jsii$Proxy) o;

            if (this.destroyAfterDeploy != null ? !this.destroyAfterDeploy.equals(that.destroyAfterDeploy) : that.destroyAfterDeploy != null) return false;
            return this.pathMetadata != null ? this.pathMetadata.equals(that.pathMetadata) : that.pathMetadata == null;
        }

        @Override
        public final int hashCode() {
            int result = this.destroyAfterDeploy != null ? this.destroyAfterDeploy.hashCode() : 0;
            result = 31 * result + (this.pathMetadata != null ? this.pathMetadata.hashCode() : 0);
            return result;
        }
    }
}
